==> nextcloud-16.0.5.tgz: nextcloud/apps/comments/l10n/vi.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Các bình luận",
    "You commented" : "Bạn đã bình luận",
    "%1$s commented" : "%1$s được bình luận",
    "{author} commented" : "{author} đã bình luận",
    "You commented on %1$s" : "Bạn đã bình luận về %1$s",
    "You commented on {file}" : "Bạn đã bình luận đối với tệp tin {file}",
    "%1$s commented on %2$s" : "%1$s đã bình luận về%2$s",
    "{author} commented on {file}" : "{author} đã bình luận về tệp tin {file}",
    "<strong>Comments</strong> for files" : "<strong>bình luận</strong> đối với các tệp tin",
    "{user} mentioned you in a comment on “{file}”" : "{user} đề cập tới bạn trong một bình luận về “{file}”",
    "Edit comment" : "Sửa bình luận",
    "Delete comment" : "Xóa bình luận",
    "New comment …" : "Tạo bình luận mới",
    "Post" : "Đăng",
    "Cancel" : "Hủy",
    "[Deleted user]" : "[Người dùng bị xoá]",
    "No comments yet, start the conversation!" : "Không có bình luận nào, bắt đầu cuộc hội thoại!",
    "More comments …" : "Xem thêm các bình luận...",
    "Save" : "Lưu",
    "Allowed characters {count} of {max}" : "Số  ký tự được còn lại là {count} trong tổng số {max}",
    "Error occurred while updating comment with id {id}" : "Có lỗi xảy ra khi cập nhật bình luận có id {id}",
    "Error occurred while posting comment" : "Có lỗi xảy ra khi đăng bình luận",
    "_%n unread comment_::_%n unread comments_" : ["%n bình luận chưa đọc"],
    "Comment" : "Bình luận"
},
"nplurals=1; plural=0;");

==> nextcloud-19.0.4.tgz: nextcloud/apps/comments/l10n/vi.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Các bình luận",
    "You commented" : "Bạn đã bình luận",
    "%1$s commented" : "%1$s được bình luận",
    "{author} commented" : "{author} đã bình luận",
    "You commented on %1$s" : "Bạn đã bình luận về %1$s",
    "You commented on {file}" : "Bạn đã bình luận đối với tệp tin {file}",
    "%1$s commented on %2$s" : "%1$s đã bình luận về%2$s",
    "{author} commented on {file}" : "{author} đã bình luận về tệp tin {file}",
    "<strong>Comments</strong> for files" : "<strong>bình luận</strong> đối với các tệp tin",
    "{user} mentioned you in a comment on “{file}”" : "{user} đề cập tới bạn trong một bình luận về “{file}”",
    "Edit comment" : "Sửa bình luận",
    "Delete comment" : "Xóa bình luận",
    "New comment …" : "Tạo bình luận mới",
    "Post" : "Đăng",
    "Cancel" : "Hủy",
    "[Deleted user]" : "[Người dùng bị xoá]",
    "No comments yet, start the conversation!" : "Không có bình luận nào, bắt đầu cuộc hội thoại!",
    "More comments …" : "Xem thêm các bình luận...",
    "Save" : "Lưu",
    "Allowed characters {count} of {max}" : "Số  ký tự được còn lại là {count} trong tổng số {max}",
    "Error occurred while retrieving comment with ID {id}" : "Xảy ra lỗi khi trích xuất bình của ID{id}",
    "Error occurred while updating comment with id {id}" : "Có lỗi xảy ra khi cập nhật bình luận có id {id}",
    "Error occurred while posting comment" : "Có lỗi xảy ra khi đăng bình luận",
    "_%n unread comment_::_%n unread comments_" : ["%n bình luận chưa đọc"],
    "Comment" : "Bình luận"
},
"nplurals=1; plural=0;");
